@@ -10,7 +10,6 @@ from magicapi.app_factory import create_app, create_handler
 app = create_app(config_settings=settings)
 handler = create_handler(app)
 
-background_router = APIRouter()
 # this requires a background router
 from magicapi.Utils.middleware import CallRoute
 
@@ -23,9 +22,8 @@ def add_routes(this_app):
     from app import Routes
 
     this_app.include_router(router)
-    this_app.include_router(background_router)
 
 
 # add_routes(app)
 
-app.include_router(router)
+app.include_router(router)
\ No newline at end of file
